FreeStyleSettings class

Represents settings used to create and draw free-style drawables.

Annotations

Constructors

FreeStyleSettings({FreeStyleMode mode = FreeStyleMode.none, Color color = Colors.black, double strokeWidth = 1})
Creates a FreeStyleSettings with the given color and strokeWidth and mode values.
const

Properties

color → Color
The color the path will be drawn with.
final
hashCode → int
The hash code for this object.
no setterinherited
mode → FreeStyleMode
Free-style painting mode.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strokeWidth → double
The stroke width the path will be drawn with.
final

Methods

copyWith({FreeStyleMode? mode, Color? color, double? strokeWidth}) → FreeStyleSettings
Creates a copy of this but with the given fields replaced with the new values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited