OvalDrawable class

A drawable of an oval.

Inheritance
Implemented types

Constructors

OvalDrawable({Paint? paint, required Size size, required Offset position, double rotationAngle = 0, double scale = 1, Set<ObjectDrawableAssist> assists = const <ObjectDrawableAssist>{}, Map<ObjectDrawableAssist, Paint> assistPaints = const <ObjectDrawableAssist, Paint>{}, bool locked = false, bool hidden = false})
Creates a new OvalDrawable with the given size and paint.

Properties

assistPaints → Map<ObjectDrawableAssist, Paint>
The paint to be used for each assist type.
finalinherited
assists → Set<ObjectDrawableAssist>
The current assist lines the object has.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hidden → bool
Whether the drawable is hidden or not.
finalinherited
isHidden → bool
no setterinherited
isNotHidden → bool
no setterinherited
locked → bool
Defines if the object drawable is locked or not. If it is locked, it won't be movable, scalable or re-sizable using the UI.
finalinherited
min_scale → double
no setterinherited
padding → EdgeInsets
Getter for padding of drawable.
no setter
paint ↔ Paint
The paint to be used for the line drawable.
getter/setter pairoverride
position → Offset
The location of the object to be painted.
finalinherited
rotationAngle → double
The rotation of the object to be painted in radians.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → double
The scale of the object to be painted.
finalinherited
size → Size
The size of the drawable.
finalinherited

Methods

copyWith({bool? hidden, Set<ObjectDrawableAssist>? assists, Offset? position, double? rotation, double? scale, Size? size, Paint? paint, bool? locked}) → OvalDrawable
Creates a copy of this but with the given fields replaced with the new values.
draw(Canvas canvas, Size size) → void
Draws the object on the provided canvas of size size.
inherited
drawAssists(Canvas canvas, Size size) → void
Draws any assist lines that the object has on canvas with size.
inherited
drawObject(Canvas canvas, Size size) → void
Draws the arrow on the provided canvas of size size.
override
getSize({double minWidth = 0.0, double maxWidth = double.infinity}) → Size
Calculates the size of the rendered object.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited