PainterSettings class

Represents all the settings used to create and draw drawables.

Annotations

Constructors

PainterSettings({FreeStyleSettings freeStyle = const FreeStyleSettings(), ObjectSettings object = const ObjectSettings(), TextSettings text = const TextSettings(), ShapeSettings shape = const ShapeSettings(), ScaleSettings scale = const ScaleSettings()})
Creates a PainterSettings with the given settings for freeStyle, object and text.
const

Properties

freeStyle → FreeStyleSettings
Settings for free-style drawables.
final
hashCode → int
The hash code for this object.
no setterinherited
object → ObjectSettings
Settings for object drawables.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → ScaleSettings
Settings for canvas scaling.
final
shape → ShapeSettings
Settings for shape drawables.
final
text → TextSettings
Settings for text drawables.
final

Methods

copyWith({FreeStyleSettings? freeStyle, ObjectSettings? object, TextSettings? text, ShapeSettings? shape, ScaleSettings? scale}) → PainterSettings
Creates a copy of this but with the given fields replaced with the new values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited