ScaleSettings class

Represents the settings of scaling the FlutterPainter.

Annotations

Constructors

ScaleSettings({bool enabled = false, double minScale = 1, double maxScale = 5})
Creates a ScaleSettings with the given enabled, minScale and maxScale values. minScale will be set to 1 if the provided value is not positive. maxScale will be set equal to minScale if the provided value is less than minScale.
const

Properties

enabled → bool
Whether scaling is enabled or not. If true, you'll be able to zoom the FlutterPainter canvas in and out.
final
hashCode → int
The hash code for this object.
no setterinherited
maxScale → double
The maximum scale that the user can "zoom in" to. Must be larger than or equal to minScale.
final
minScale → double
The minimum scale that the user can "zoom out" to. Must be positive.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? enabled, double? minScale, double? maxScale}) → ScaleSettings
Creates a copy of this but with the given fields replaced with the new values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited